@@ -7,8 +7,7 @@ import cltoolbox
 import numpy as np
 import typic
 from cltoolbox.rst_text_formatter import RSTHelpFormatter
-
-from .. import tsutils
+from toolbox_utils import tsutils
 
 warnings.filterwarnings("ignore")
 
