@@ -8,8 +8,7 @@ import pandas as pd
 import typic
 from cltoolbox.rst_text_formatter import RSTHelpFormatter
 from scipy.stats import t
-
-from .. import tsutils
+from toolbox_utils import tsutils
 
 try:
     from typing import Literal
