@@ -4,8 +4,7 @@
 import cltoolbox
 import typic
 from cltoolbox.rst_text_formatter import RSTHelpFormatter
-
-from .. import tsutils
+from toolbox_utils import tsutils
 
 
 @cltoolbox.command("pca", formatter_class=RSTHelpFormatter)
