@@ -9,145 +9,22 @@ from typing import List, Optional, Tuple, Union
 import cltoolbox
 import numpy as np
 import pandas as pd
+import plottoolbox
 import typic
 from cltoolbox.rst_text_formatter import RSTHelpFormatter
-
-from .. import tsutils
+from plottoolbox import plotutils
+from toolbox_utils import tsutils
 
 try:
     from typing import Literal
 except ImportError:
     from typing_extensions import Literal
 
-
 warnings.filterwarnings("ignore")
 
-ldocstrings = tsutils.docstrings
-ldocstrings[
-    "xydata"
-] = """If the input 'x,y' dataset(s) is organized as
-            'index,x1,y1,x2,y2,x3,y3,...,xN,yN' then the 'index' is ignored.
-            If there is one 'x,y' dataset then it can be organized as 'index,y'
-            where 'index' is used for 'x'.  The "columns" keyword can be used
-            to duplicate or change the order of all the data columns."""
-ldocstrings[
-    "ydata"
-] = """Data must be organized as 'index,y1,y2,y3,...,yN'.  The 'index' is
-            ignored and all data columns are plotted.  The "columns" keyword
-            can be used to duplicate or change the order of all the data
-            columns."""
-ldocstrings[
-    "yone"
-] = """Data must be organized as 'index,y1'.  Can only plot one series."""
-ldocstrings[
-    "secondary_axis"
-] = """[optional, default is False]
-
-        * list/tuple: Give the column numbers or names to plot on secondary
-          y-axis.
-        * (string, string): The first string is the units of the primary axis,
-          the second string is the units of the secondary axis if you want just
-          unit conversion.  Use any units or combination thereof from the
-          "pint" library.
-        * (callable, callable): Functions relating relationship between
-          primary and secondary axis.  First function will be given the values
-          on primary axis and returns valueis on secondary axis.  Second function
-          will be do the inverse.  Python API only.
-        * string: One of pre-built (callable, callable) combinations.  Can be
-          one of "period"."""
-
-MARKER_LIST = [
-    ".",
-    ",",
-    "o",
-    "v",
-    "^",
-    "<",
-    ">",
-    "1",
-    "2",
-    "3",
-    "4",
-    "8",
-    "s",
-    "p",
-    "*",
-    "h",
-    "H",
-    "+",
-    "D",
-    "d",
-    "|",
-    "_",
-]
-
-LINE_LIST = ["-", "--", "-.", ":", "solid", "dashed", "dashdot", "dotted"]
-
-HATCH_LIST = ["/", "\\", "|", "-", "+", "x", "o", "O", ".", "*"]
-
-
-def _know_your_limits(xylimits, axis="arithmetic"):
-    """Establish axis limits.
-
-    This defines the xlim and ylim as lists rather than strings.
-    Might prove useful in the future in a more generic spot.  It
-    normalizes the different representations.
-    """
-    nlim = tsutils.make_list(xylimits, n=2)
-
-    if axis == "normal":
-        if nlim is None:
-            nlim = [None, None]
-        if nlim[0] is None:
-            nlim[0] = 0.01
-        if nlim[1] is None:
-            nlim[1] = 0.99
-        if nlim[0] < 0 or nlim[0] > 1 or nlim[1] < 0 or nlim[1] > 1:
-            raise ValueError(
-                tsutils.error_wrapper(
-                    f"""
-Both limits must be between 0 and 1 for the 'normal', 'lognormal', or 'weibull'
-axis.
-
-Instead you have {nlim}.
-"""
-                )
-            )
-
-    if nlim is None:
-        return nlim
-
-    if nlim[0] is not None and nlim[1] is not None and nlim[0] >= nlim[1]:
-        raise ValueError(
-            tsutils.error_wrapper(
-                f"""
-The second limit must be greater than the first.
-
-You gave {nlim}.
-"""
-            )
-        )
-
-    if (
-        axis == "log"
-        and (nlim[0] is not None and nlim[0] <= 0)
-        or (nlim[1] is not None and nlim[1] <= 0)
-    ):
-        raise ValueError(
-            tsutils.error_wrapper(
-                f"""
-If log plot cannot have limits less than or equal to 0.
-
-You have {nlim}.
-"""
-            )
-        )
-
-    return nlim
-
 
 @cltoolbox.command("plot", formatter_class=RSTHelpFormatter)
-@tsutils.doc(tsutils.docstrings)
+@tsutils.doc(plotutils.ldocstrings)
 def plot_cli(
     input_ts="-",
     columns=None,
@@ -1034,13 +911,6 @@ def plot(
     # cltoolbox
     legend = bool(legend == "" or legend == "True" or legend is None)
 
-    import matplotlib
-
-    matplotlib.use("Agg")
-    import matplotlib.pyplot as plt
-    from matplotlib.ticker import FixedLocator
-    from plottoolbox import plottoolbox
-
     tsd = tsutils.common_kwds(
         input_tsd=input_ts,
         skiprows=skiprows,
@@ -1057,261 +927,6 @@ def plot(
         por=por,
     )
 
-    if (
-        type in ["bootstrap", "heatmap", "autocorrelation", "lag_plot"]
-        and len(tsd.columns) != 1
-    ):
-        raise ValueError(
-            tsutils.error_wrapper(
-                f"""
-The '{type}' plot can only work with 1 time-series in the DataFrame.
-The DataFrame that you supplied has {len(tsd.columns)} time-series.
-"""
-            )
-        )
-
-    # This is to help pretty print the frequency
-    try:
-        try:
-            pltfreq = str(tsd.index.freq, "utf-8").lower()
-        except TypeError:
-            pltfreq = str(tsd.index.freq).lower()
-        if pltfreq.split(" ")[0][1:] == "1":
-            beginstr = 3
-        else:
-            beginstr = 1
-        if pltfreq == None:
-            short_freq = ""
-        else:
-            # short freq string (day) OR (2 day)
-            short_freq = f"({pltfreq[beginstr:-1]})"
-    except AttributeError:
-        short_freq = ""
-
-    if legend_names:
-        lnames = legend_names
-        if len(lnames) != len(set(lnames)):
-            raise ValueError(
-                tsutils.error_wrapper(
-                    """
-Each name in legend_names must be unique.
-"""
-                )
-            )
-        if len(tsd.columns) == len(lnames):
-            renamedict = dict(list(zip(tsd.columns, lnames)))
-        elif type in ["xy", "double_mass"] and (
-            len(tsd.columns) // 2 == len(lnames) or len(tsd.columns) == 1
-        ):
-            renamedict = dict(list(zip(tsd.columns[2::2], lnames[1:])))
-            renamedict[tsd.columns[1]] = lnames[0]
-        else:
-            raise ValueError(
-                tsutils.error_wrapper(
-                    f"""
-For 'legend_names' and most plot types you must have the same number of comma
-separated names as columns in the input data.  The input data has {len(tsd.columns)} where the
-number of 'legend_names' is {len(lnames)}.
-
-If `type` is 'xy' or 'double_mass' you need to have legend names as
-l1,l2,l3,...  where l1 is the legend for x1,y1, l2 is the legend for x2,y2,
-...etc.
-"""
-                )
-            )
-        tsd.rename(columns=renamedict, inplace=True)
-    else:
-        lnames = tsd.columns
-
-    if colors is not None and "auto" in colors:
-        colors = None
-
-    if linestyles is None:
-        linestyles = " "
-    elif "auto" in linestyles:
-        linestyles = LINE_LIST
-
-    if bar_hatchstyles is None:
-        bar_hatchstyles = " "
-    elif "auto" in bar_hatchstyles:
-        bar_hatchstyles = HATCH_LIST
-
-    if markerstyles is None:
-        markerstyles = " "
-    elif "auto" in markerstyles:
-        markerstyles = MARKER_LIST
-
-    if "auto" not in style:
-
-        nstyle = style
-        if len(nstyle) != len(tsd.columns):
-            raise ValueError(
-                tsutils.error_wrapper(
-                    f"""
-You have to have the same number of style strings as time-series to plot.
-You supplied '{style}' for style which has {len(nstyle)} style strings,
-but you have {len(tsd.columns)} time-series.
-"""
-                )
-            )
-        colors = []
-        markerstyles = []
-        linestyles = []
-        for st in nstyle:
-            colors.append(st[0])
-            if len(st) == 1:
-                markerstyles.append(" ")
-                linestyles.append("-")
-                continue
-            if st[1] in MARKER_LIST:
-                markerstyles.append(st[1])
-                try:
-                    linestyles.append(st[2:])
-                except IndexError:
-                    linestyles.append(" ")
-            else:
-                markerstyles.append(" ")
-                linestyles.append(st[1:])
-    if linestyles is None:
-        linestyles = [" "]
-    else:
-        linestyles = [" " if i in ["  ", None] else i for i in linestyles]
-    markerstyles = [" " if i is None else i for i in markerstyles]
-
-    if colors is not None:
-        icolors = itertools.cycle(colors)
-    else:
-        icolors = None
-    imarkerstyles = itertools.cycle(markerstyles)
-    ilinestyles = itertools.cycle(linestyles)
-
-    # Only for bar, barh, bar_stacked, and barh_stacked.
-    ibar_hatchstyles = itertools.cycle(bar_hatchstyles)
-
-    if (
-        logx is True
-        or logy is True
-        or norm_xaxis is True
-        or norm_yaxis is True
-        or lognorm_xaxis is True
-        or lognorm_yaxis is True
-    ):
-        warnings.warn(
-            """
-*
-*   The --logx, --logy, --norm_xaxis, --norm_yaxis, --lognorm_xaxis, and
-*   --lognorm_yaxis options are deprecated.
-*
-*   For --logx use --xaxis="log"
-*   For --logy use --yaxis="log"
-*   For --norm_xaxis use --type="norm_xaxis"
-*   For --norm_yaxis use --type="norm_yaxis"
-*   For --lognorm_xaxis use --type="lognorm_xaxis"
-*   For --lognorm_yaxis use --type="lognorm_yaxis"
-*
-"""
-        )
-
-    if xaxis == "log":
-        logx = True
-    if yaxis == "log":
-        logy = True
-
-    if type in ["norm_xaxis", "lognorm_xaxis", "weibull_xaxis"]:
-        xaxis = "normal"
-        if logx is True:
-            logx = False
-            warnings.warn(
-                """
-*
-*   The --type={1} cannot also have the xaxis set to {0}.
-*   The {0} setting for xaxis is ignored.
-*
-""".format(
-                    xaxis, type
-                )
-            )
-
-    if type in ["norm_yaxis", "lognorm_yaxis", "weibull_yaxis"]:
-        yaxis = "normal"
-        if logy is True:
-            logy = False
-            warnings.warn(
-                tsutils.error_wrapper(
-                    """
-The --type={1} cannot also have the yaxis set to {0}.
-The {0} setting for yaxis is ignored.
-""".format(
-                        yaxis, type
-                    )
-                )
-            )
-
-    xlim = _know_your_limits(xlim, axis=xaxis)
-    ylim = _know_your_limits(ylim, axis=yaxis)
-    plot_styles = plot_styles + ["no-latex"]
-    style_loc = os.path.join(
-        os.path.dirname(__file__), os.pardir, "SciencePlots_styles"
-    )
-    plot_styles = [
-        os.path.join(style_loc, i + ".mplstyle")
-        if os.path.exists(os.path.join(style_loc, i + ".mplstyle"))
-        else i
-        for i in plot_styles
-    ]
-    plt.style.use(plot_styles)
-
-    _, ax = plt.subplots(figsize=figsize)
-
-    if not isinstance(tsd.index, pd.DatetimeIndex) and type == "time":
-        raise ValueError(
-            tsutils.error_wrapper(
-                """
-The index is not a datetime index and cannot be plotted as a time-series.
-Instead of `type="time"` you might want `type="xy"` or change the index to
-a datetime index.
-"""
-            )
-        )
-
-    if type in ["xy", "double_mass"]:
-        if tsd.shape[1] > 1 and tsd.shape[1] % 2 != 0:
-            raise AttributeError(
-                tsutils.error_wrapper(
-                    f"""
-The 'xy' and 'double_mass' types must have an even number of columns arranged
-as x,y pairs or an x-index and one y data column.  You supplied {tsd.shape[1]} columns.
-"""
-                )
-            )
-        colcnt = tsd.shape[1] // 2
-    elif type in [
-        "norm_xaxis",
-        "norm_yaxis",
-        "lognorm_xaxis",
-        "lognorm_yaxis",
-        "weibull_xaxis",
-        "weibull_yaxis",
-    ]:
-        colcnt = tsd.shape[1]
-
-    if type in [
-        "xy",
-        "double_mass",
-        "norm_xaxis",
-        "norm_yaxis",
-        "lognorm_xaxis",
-        "lognorm_yaxis",
-        "weibull_xaxis",
-        "weibull_yaxis",
-    ]:
-        plotdict = {
-            (False, True): ax.semilogy,
-            (True, False): ax.semilogx,
-            (True, True): ax.loglog,
-            (False, False): ax.plot,
-        }
-
     if type == "autocorrelation":
         pltr = plottoolbox.autocorrelation(
             input_ts=input_ts,
