@@ -7,8 +7,7 @@ import warnings
 import cltoolbox
 import numpy as np
 from cltoolbox.rst_text_formatter import RSTHelpFormatter
-
-from .. import tsutils
+from toolbox_utils import tsutils
 
 warnings.filterwarnings("ignore")
 
