@@ -6,8 +6,7 @@ import warnings
 
 import cltoolbox
 from cltoolbox.rst_text_formatter import RSTHelpFormatter
-
-from .. import tsutils
+from toolbox_utils import tsutils
 
 warnings.filterwarnings("ignore")
 
