@@ -4,8 +4,9 @@ from unittest import TestCase
 import pandas as pd
 import pytest
 from pandas.testing import assert_frame_equal
+from toolbox_utils import tsutils
 
-from tstoolbox import tstoolbox, tsutils
+from tstoolbox import tstoolbox
 
 
 class TestRead(TestCase):
