@@ -5,8 +5,9 @@ import subprocess
 from unittest import TestCase
 
 from pandas.testing import assert_frame_equal
+from toolbox_utils import tsutils
 
-from tstoolbox import tstoolbox, tsutils
+from tstoolbox import tstoolbox
 
 
 class TestAddTrend(TestCase):
