@@ -2,28 +2,34 @@
 
 import shlex
 import subprocess
+from io import BytesIO
 from unittest import TestCase
 
-import pandas
+import pandas as pd
 import pytest
 from pandas.testing import assert_frame_equal
+from toolbox_utils import tsutils
 
-from tstoolbox import tstoolbox, tsutils
+from tstoolbox import tstoolbox
 
 
 class TestAggregate(TestCase):
     def setUp(self):
-        dr = pandas.date_range("2011-01-01", periods=2, freq="D")
+        dr = pd.date_range("2011-01-01", periods=2, freq="D")
 
-        ts = pandas.Series([2, 2], index=dr)
-        self.aggregate_direct_mean = pandas.DataFrame(ts, columns=["Value::mean"])
+        ts = pd.Series([2, 2], index=dr)
+        self.aggregate_direct_mean = pd.DataFrame(ts, columns=["Value::mean"])
         self.aggregate_direct_mean.index.name = "Datetime"
-        self.aggregate_direct_mean = tsutils.memory_optimize(self.aggregate_direct_mean)
+        self.aggregate_direct_mean = tsutils.memory_optimize(
+            self.aggregate_direct_mean
+        ).astype("Int64")
 
-        ts = pandas.Series([48, 48], index=dr)
-        self.aggregate_direct_sum = pandas.DataFrame(ts, columns=["Value::sum"])
+        ts = pd.Series([48.0, 48.0], index=dr)
+        self.aggregate_direct_sum = pd.DataFrame(ts, columns=["Value::sum"])
         self.aggregate_direct_sum.index.name = "Datetime"
-        self.aggregate_direct_sum = tsutils.memory_optimize(self.aggregate_direct_sum)
+        self.aggregate_direct_sum = tsutils.memory_optimize(
+            self.aggregate_direct_sum
+        ).astype("Float64")
 
         self.aggregate_cli_mean = b"""Datetime,Value::mean
 2011-01-01,2.0
@@ -39,15 +45,15 @@ class TestAggregate(TestCase):
         """Test daily mean aggregation."""
         out = tstoolbox.aggregate(
             statistic="mean", groupby="daily", input_ts="tests/data_flat.csv"
-        ).astype("Int64")
-        assert_frame_equal(out, self.aggregate_direct_mean)
+        ).astype("Float64")
+        assert_frame_equal(out, self.aggregate_direct_mean, check_dtype=False)
 
     def test_aggregate_direct_sum(self):
         """Test daily mean summation."""
         out = tstoolbox.aggregate(
             statistic="sum", groupby="daily", input_ts="tests/data_flat.csv"
-        )
-        assert_frame_equal(out, self.aggregate_direct_sum)
+        ).astype("Float64")
+        assert_frame_equal(out, self.aggregate_direct_sum, check_dtype=False)
 
     def test_aggregate_cli_mean(self):
         """Test CLI mean, daily (by default) aggregation."""
@@ -57,8 +63,12 @@ class TestAggregate(TestCase):
             '--input_ts="tests/data_flat.csv"'
         )
         args = shlex.split(args)
-        out = subprocess.Popen(args, stdout=subprocess.PIPE).communicate()[0]
-        self.assertEqual(out, self.aggregate_cli_mean)
+        out = pd.read_csv(
+            BytesIO(subprocess.Popen(args, stdout=subprocess.PIPE).communicate()[0])
+        )
+        assert_frame_equal(
+            out, pd.read_csv(BytesIO(self.aggregate_cli_mean)), check_dtype=False
+        )
 
     def test_aggregate_cli_sum(self):
         """Test CLI summation, daily (by default) aggregation."""
