@@ -4,33 +4,36 @@ import shlex
 import subprocess
 from unittest import TestCase
 
-import pandas
+import pandas as pd
 from pandas.testing import assert_frame_equal
+from toolbox_utils import tsutils
 
-from tstoolbox import tstoolbox, tsutils
+from tstoolbox import tstoolbox
 
 
 class TestConvert(TestCase):
     def setUp(self):
-        dr = pandas.date_range("2000-01-01", periods=2, freq="D")
-        ts = pandas.Series([4.5, 4.6], index=dr)
-        self.compare_direct_01 = pandas.DataFrame(ts, columns=["Value::convert"])
+        dr = pd.date_range("2000-01-01", periods=2, freq="D")
+        ts = pd.Series([4.5, 4.6], index=dr)
+        self.compare_direct_01 = pd.DataFrame(ts, columns=["Value::convert"])
         self.compare_direct_01.index.name = "Datetime"
         self.compare_direct_01 = tsutils.memory_optimize(self.compare_direct_01)
 
-        dr = pandas.date_range("2000-01-01", periods=2, freq="D")
-        ts = pandas.Series([11.0, 11.2], index=dr)
-        self.compare_direct_02 = pandas.DataFrame(ts, columns=["Value::convert"])
+        dr = pd.date_range("2000-01-01", periods=2, freq="D")
+        ts = pd.Series([11.0, 11.2], index=dr)
+        self.compare_direct_02 = pd.DataFrame(ts, columns=["Value::convert"])
         self.compare_direct_02.index.name = "Datetime"
-        self.compare_direct_02 = tsutils.memory_optimize(self.compare_direct_02)
+        self.compare_direct_02 = (
+            tsutils.memory_optimize(self.compare_direct_02)
+        ).astype("Float64")
 
         self.compare_cli_01 = b"""Datetime,Value::convert
 2000-01-01,4.5
 2000-01-02,4.6
 """
         self.compare_cli_02 = b"""Datetime,Value::convert
-2000-01-01,11.0
-2000-01-02,11.2
+2000-01-01,11.9
+2000-01-02,12.12
 """
 
     def test_convert_direct_01(self):
@@ -40,7 +43,9 @@ class TestConvert(TestCase):
 
     def test_convert_direct_02(self):
         """Test of convert API with set factor and offset."""
-        out = tstoolbox.convert(input_ts="tests/data_simple.csv", factor=2, offset=2)
+        out = (
+            tstoolbox.convert(input_ts="tests/data_simple.csv", factor=2, offset=2)
+        ).astype("Float64")
         assert_frame_equal(out, self.compare_direct_02)
 
     def test_convert_cli_01(self):
@@ -54,7 +59,7 @@ class TestConvert(TestCase):
         """Test of CLI convert set factor and offset."""
         args = (
             "tstoolbox convert "
-            "--factor=2 "
+            "--factor=2.2 "
             "--offset=2 "
             '--input_ts="tests/data_simple.csv"'
         )
