@@ -6,8 +6,9 @@ from unittest import TestCase
 import pandas as pd
 import pytest
 from pandas.testing import assert_index_equal
+from toolbox_utils import tsutils
 
-from tstoolbox import tstoolbox, tsutils
+from tstoolbox import tstoolbox
 
 
 class TestRead(TestCase):
